<?php 

/*

Theme: usnaaa-cccg

REVISION HISTORY

10/8/2015 - sch75 - revised custom theme support to allow flex width on header logos 
	as some were being inadvertently cropped (also required CSS mods).  Changed names 
	of left side menu to primary and footer menu to social.
9/28/2015 - sch75 - added function to default tagline on new sites to read 
	'Set this Tagline in General Settings'
9/25/2015 - sch75 - swapped order of sidebar registrations to determin if new sites get 
	default widgets assigned to right side vice left side.
9/21/2015 - sch75 - added <br /> before widget areas in $left_sidebar and $right_sidebar
9/21/2015 - sch75 - moved widget <br /> to after widgets to keep right columm white space
	same as left and center

*/



if ( ! isset( $content_width ) ) {
	$content_width = 980;           // Content Width is a theme feature, 
									// first introduced in Version 2.6. This feature
									// sets the maximum allowed width for any content 
									// in the theme, like images added to posts.
}

function usnaaa_filter_wp_title( $currenttitle, $sep, $seplocal ) {
	$site_name = get_bloginfo( 'name' );				// Grabs the site name
	$full_title = $site_name . $currenttitle;       	// Adds the site name after the current page title
	if ( is_front_page() || is_home() ) {           	// If we are on the front_page or homepage append the description
		$site_desc = get_bloginfo( 'description' );     // Grab the Site Description
		$full_title .= ' ' . $sep . ' ' . $site_desc;   // Append Site Description to title
		}
	return $full_title;
	}
		
add_filter( 'wp_title', 'usnaaa_filter_wp_title', 10, 3 );   // Hook into 'wp_title'
		
add_theme_support( 'post-thumbnails', array( 'post', 'page' ) );

/*
 * The default "logo" in the upper right header is contained within the graphics files 
 * provided in the theme.  An appropriate logo may be substituted for the default logo
 * by "customing" the theme.
 */
 		
add_theme_support( 'custom-header', array(
	'flex-width'    => true,
	'width'         => 120,
	'flex-height'    => true,
	'height'        => 120,	
	'default-image' => get_template_directory_uri() . '/graphix/banner-logo-120x120.jpg',
) );
		
/* The style editor will provide editors with a similar WYSIWYG appearance of 
 * material as will be displayd on the pages.  
 */	
		
add_editor_style( 'style-editor.css' );
		
add_post_type_support ( 'page', 'excerpt' );

/*
 * The theme has four menus.
 * 	Two of the menus are required to provide the tabs at the top:
 *  	- Left top tabs (left side, will display left-to-right)
 *  	- Right top tabs (right side, will display right-to-left)
 *  The site menu in the left hand column of all pages EXCEPT full-width
 *  The footer media "buttons" - these buttons are set via a dynamic menu vice being hard
 *  	coded into the footer.
 */

register_nav_menus(
	array(
		'primary'             =>   __( 'Primary Menu',                'usnaaa-cccg' ),
		'top-tabs-left'       =>   __( 'Left Top Tabs',               'usnaaa-cccg' ),
		'top-tabs-right'      =>   __( 'Right Top Tabs',              'usnaaa-cccg' ),
		'social'              =>   __( 'Footer Social Media Buttons', 'usnaaa-cccg' )
			)
		);

$right_sidebar = array(
		'name'          => 'Right Column',  //Sidebar Display Name
		'id'            => 'right-column',  //sidebar-slug
		'description'   => 'Widgets placed here will appear in the right column of the three-column pages',  //descripion
		'before_widget' => '',       //HTML markup before widget
		'after_widget'  => '<br />',       //HTML markup after widget
		'before_title'  => '<h6>',   //HTML markup before widget title
		'after_title'   => '</h6>',  //HTML markup after widget title
		);
		
register_sidebar( $right_sidebar );		
		
$left_sidebar = array(
		'name'          => 'Left Column',  //Sidebar Display Name
		'id'            => 'left-column',  //sidebar-slug
		'description'   => 'Widgets placed here appear below the menu',  //descripion
		'before_widget' => '',       //HTML markup before widget
		'after_widget'  => '<br />',       //HTML markup after widget
		'before_title'  => '<h6>',   //HTML markup before widget
		'after_title'   => '</h6>',  //HTML markup after widget
		);
		
register_sidebar( $left_sidebar );

		
/*
 * A function to determine menu depth.  Third level items in the site menu are not
 * displayed from top level pages.  If the viewer is looking at a deeper level, more
 * menu items will appear.
 */
		
function wt_get_depth($id = '', $depth = '', $i = 0) {
	global $wpdb;
	global $post;
	if($depth == ''){
		if(is_page())
		{
			if($id == '')
			{
				$id = $post->ID;
			}
			$depth = $wpdb->get_var("SELECT post_parent FROM $wpdb->posts WHERE ID = '".$id."'");
			return wt_get_depth($id, $depth, $i);
		}
	}
	elseif($depth == "0")
	{
		return $i;
	}
	else
	{
		$depth = $wpdb->get_var("SELECT post_parent FROM $wpdb->posts WHERE ID = '".$depth."'");
		$i++;
		return wt_get_depth($id, $depth, $i);
	}
};

/*
 * A function to change the default tagline
 */

function set_default_tagline($blog_id)
	{ switch_to_blog($blog_id);update_option( 'blogdescription', 'Set this Tagline in General Settings' );
	 restore_current_blog();} 
	 
add_action('wpmu_new_blog', 'set_default_tagline' );