<?php
/**
 * Header template for the USNAAA-CCCG theme
 *
 * Displays all of the <head> section and everything up to <div id="main">.
 
** REVISION HISTORY

10/4/1025 - by sch75 - added favicons for apple and microsoft
9/30/2015 - by sch75 - added stylesheet logic for mobile devices
9/25/2015 - by sch75 - added str_replace to $imageID to change hyphens to whitespace
9/23/2015 - by sch75 - added <meta name='robots' content='all' /> 
9/21/2015 - by sch75 - changed featured image so this if no featured image is set for the page,
	a random img is selected from the theme /graphix folder vice instructions on how to 
	select and set a featured image.
9/20/2015 - by sch75 - corrected minor typos in notes. 
 
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>

<title><?php wp_title( '|', true, 'right' ); ?></title>
<meta http-equiv="Content-Type" content="<?php bloginfo( 'html_type' ); ?>; charset=<?php bloginfo( 'charset' ); ?>">

<?php if ( wp_is_mobile() )  : ?>

	<link rel="stylesheet" href="<?php bloginfo( 'stylesheet_directory' ); ?>/style-mobile.css" media="screen, print" type="text/css" />
	<meta name="viewport" content="width=device-width, initial-scale=1.0, user-scalable=1">
	<?php	else: ?>

	<link rel="stylesheet" href="<?php bloginfo( 'stylesheet_url' ); ?>" media="screen, print" type="text/css" />	

<?php endif; ?>

<link rel="SHORTCUT ICON" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/favicon.ico" type="image/x-icon" />
<link rel="apple-touch-icon" sizes="57x57" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/apple-touch-icon-57x57.png">
<link rel="apple-touch-icon" sizes="60x60" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/apple-touch-icon-60x60.png">
<link rel="apple-touch-icon" sizes="72x72" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/apple-touch-icon-72x72.png">
<link rel="apple-touch-icon" sizes="76x76" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/apple-touch-icon-76x76.png">
<link rel="apple-touch-icon" sizes="114x114" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/apple-touch-icon-114x114.png">
<link rel="apple-touch-icon" sizes="120x120" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/apple-touch-icon-120x120.png">
<link rel="icon" type="image/png" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/favicon-32x32.png" sizes="32x32">
<link rel="icon" type="image/png" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/favicon-96x96.png" sizes="96x96">
<link rel="icon" type="image/png" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/favicon-16x16.png" sizes="16x16">
<link rel="manifest" href="<?php bloginfo( 'stylesheet_directory' ); ?>/graphix/favicons/manifest.json">
<meta name="msapplication-TileColor" content="#b9ae75">

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>><!-- body_class() inserts wp clasifications of page -->
<div id="top-bar-ribbons"></div><!-- end of the top-bar-chapter-ribbons (a strip of ribbons) -->

<div id="banner">

		<a href="<?php echo home_url(); ?>">
		<img id="usnaaa" src="<?php echo get_template_directory_uri(); ?>/graphix/banner-graphic-usna-105x140.gif" alt="the banner graphic" title="Home Page" />
		
		
<?php if ( get_header_image() ) : ?>
	
			<img  id="cccg-logo" src="<?php header_image(); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>">
		
	
	<?php endif; ?>		
		
		</a>
		
	<div id="banner-text">
	<p id="usna">U S NAVAL ACADEMY ALUMNI ASSOCIATION</p>
	<p id="cccg"><?php echo get_bloginfo('description'); ?></p>
	</div><!-- end of banner-text -->
	
	
</div><!-- end of banner -->


<div id="top-tabs">

	<?php
		$top_tabs_left = array(
		'theme_location' => 'top-tabs-left',
		'container_id'   => 'top-tabs-left',
		'depth'          => 1
		); ?>
							
	<?php wp_nav_menu( $top_tabs_left ); ?> 
	
	<?php
		$top_tabs_right = array(
		'theme_location' => 'top-tabs-right',
		'container_id'   => 'top-tabs-right',
		'depth'          => 1
		); ?>
							
	<?php wp_nav_menu( $top_tabs_right ); ?>
	
</div> <!-- end of top-tabs  -->

<div id="wrapper">
	<div id="page-featured-image-graphic">
	
<!-- The page-featured-image-graphic is composed by layering three elements by absolute position.
	The first (bottom) layer is an image, the page "Featured Image" selected by page
	authors in the page editor.  Only the top 149px and right 640px 
	of the image will display.  If no page "Featured Image" has been set, a random image
	is rated in from a library on images contained in the theme /graphix folder.
	
	The second layer is a mask of two slanted white bars of increasing opacity and the 
	dark blue backround used for the third layer of the imageID.
	  
	On static pages (aka'pages') the imageID is the post name of the uppermost parent in the
	page hierachy.  For posts, the image ID is a fixed phrase defined in this file.  For 
	page not found (404) errors, the image ID is an error message.  --> 
	
		

<!-- first (bottom) layer
 	If the page has an assigned featured image, it is called in full size.  If the page is
	a 404 (not found) page, then no image is printed.  If there is no featured image set, 
	yet, then instructions on how to select and set a featured image are provided.     -->

	<?php if(has_post_thumbnail()):echo the_post_thumbnail('full');
		elseif(is_404()):;
		else: ?>
		
		<img src="<?php echo get_template_directory_uri(); ?>/graphix/page-featured-image-random-default"
		
		<?php endif; ?>

<!-- second layer -->
		<div id="page-featured-image-mask">
			<img src="<?php echo get_template_directory_uri(); ?>/graphix/header-image-mask-990x149.png" alt="image-mask" />
		</div><!-- end of page-featured-image-mask -->

<!-- third (top) layer 
	-->
		<div id="page-featured-image-title">
		
		<?php
// Define the $imageID variable
		$imageID = '';
		
// Determine if the current page is a page or a post.
		$postType=get_post_type();
		
// Pages get the slug of the highest parent:
		
		if($postType=='page') {
			global $post;
// Get an array of Ancestors and Parents if they exist
			$parents = get_post_ancestors( $post->ID );
// Get the top Level page->ID count base 1, array base 0 so -1 
			$id = ($parents) ? $parents[count($parents)-1]: $post->ID;
// Get the parent and set the $class with the page slug (post_name)
	        $parent = get_page( $id );
			$imageID = $parent->post_name;
// Change any hyphens in the $imageID to whitespace, capitalize the title
			$imageID = str_replace("-", " ", $imageID);
			$imageID = ucwords($imageID);
			$uceXceptions = array (" A "," An "," The "," In "," Of "," On "," At "," To "," From "," By "," Down "," Up "," Over "," With "," And "," As "," But "," Or "," For "," Nor "," Yet ");
			$ucrePlacements = array (" a "," an "," the "," in "," of "," on "," at "," to "," from "," by "," down "," up "," over "," with "," & "," as "," but "," or "," for "," nor "," yet ");
			$imageID = str_replace($uceXceptions, $ucrePlacements, $imageID);
		} 
		
// On the posts page:

		elseif($postType=='post') {
		$imageID = 'News & Events';}
		
// In the page not found (404) page:

		elseif(is_404()) {
		$imageID = 'OOOooh NOOoooo!';
		}
		;?>
		
		<p><?php if($imageID=='Home'):echo 'Welcome';else: echo $imageID;endif; ?>
		</p>
		
		</div><!-- end of page-featured-image-title -->

	</div><!-- page-featured-image-graphic -->
	
	<div id="content">
	
<!-- End of the themed header.	Still within:

<body> 
	<div id="wrapper">
		<div id="content">


-->